<?php
/*
  Plugin Name: Azameo Retargeting
  Plugin URI: http://dashboard.azameo.fr/register
  Description: Azameo Retargeting and Facebook Ads is the world’s easiest ad platform for WooCommerce and Wordpress: Show your products and latest content to turn prospects into customers.
  Author: Azameo
  Version: 1.3.6
  Author URI: http://www.azameo.fr/
 */

/**
 * Copyright (c) 2017 Azameo. All rights reserved.
 *
 * Released under the GPL license
 * http://www.opensource.org/licenses/gpl-license.php
 *
 * This is an add-on for WordPress
 * http://wordpress.org/
 *
 * **********************************************************************
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * **********************************************************************
 */

//Site global info
$sys_url = get_bloginfo('url');
$sys_email = get_bloginfo('admin_email');
$blog_url = parse_url($sys_url);
$trackerName = str_replace(".", "", $blog_url["host"]);
if (substr($trackerName, 0, 3) === "www") {
	$trackerName = substr($trackerName, 3);
}
$register_url = 'http://dashboard.azameo.fr/register?email=' . $sys_email . '&siteweb=' . $sys_url . '&trackername=' . $trackerName . '&origin=wordpress';

register_activation_hook(__FILE__, 'plugin_activated');
//this action is executed after loads its core, after registering all actions, finds out what page to execute and before producing the actual output(before calling any action callback)
add_action("admin_init", "display_options");
add_action('wp_head', 'azameo_add_tracking_code');
//this action callback is triggered to put product specific conversion tracking pixel in thank you page
add_action('woocommerce_thankyou', 'thankyou_page');
//this action callback is triggered when wordpress is ready to add new items to menu.
add_action("admin_menu", "add_new_menu_items");
//the action is executed after when the API is called,
add_action('rest_api_init', function () {
	register_rest_route(
		'azameo/v1',
		'/productsfeed(?:/(?P<currency>\d+))?(?:/(?P<sudo>\d+))?',
		array(
			'methods' => WP_REST_Server::READABLE, //'GET'
			'callback' => 'products_feed',
			'args' => array(
				'currency',
			),
		)
	);
});
//this action is executed in the footer
add_action('wp_footer','contactform_wp_footer');


/**
 * When the API is called (once by day max) build a XML file with products data
 * Since 1.2.2
 * @param WP_REST_Request $request
 * @return string
 */
function products_feed(WP_REST_Request $request)
{

	try {

		($request['sudo'] === 'true') ? $sudo = true : $sudo = false; // forced xml file update
		($request['currency'] === 'true') ? $currency =  true : $currency = false; // to display (or not) currencies
		$file = wp_upload_dir()['basedir'] . '/xmlproductsfeed.xml';
		$now = strtotime( '+2 hours', date("Y-m-d H:i:s"));
		$file_modification_authorization_date = strtotime('+1 day +2 hours', filemtime($file)); //we can modify file if the last modification was do 1 day ago

		//if file never generate or if now is after the file modification authorization date, do the xml file
		if (!file_exists($file) || $now > $file_modification_authorization_date || $sudo == true) {

			$args = array(
				'post_type'      => 'product',
				'posts_per_page' => - 1, // -1 all posts in 1 page
			);

			$xml = '<?xml version="1.0" encoding="UTF-8" ?>
<rss xmlns:g="http://base.google.com/ns/1.0">
    <channel>
        <title>' . get_bloginfo_rss( "name" ) . '</title>
        <link>' . get_bloginfo_rss( "wpurl" ) . '</link>';

			$loop = new WP_Query( $args );

			while ( $loop->have_posts() ) : $loop->the_post();
				global $product;
//				print_r($product);

				if ($product->get_sale_price() == null && $product->get_regular_price() == null) {
					$price = $product->get_price();
					$saleprice = $product->get_price();
				}
				else {
					if ($product->get_sale_price() == null || $product->get_sale_price() == '') {
						$price = $product->get_regular_price();
					}
					else {
						$price = $price = $product->get_sale_price();
					}

					if ($product->get_regular_price() == null || $product->get_regular_price() == '') {
						$saleprice = $product->get_sale_price();
					}
					else {
						$saleprice = $product->get_regular_price();
					}
				}

				$xml .= '
        <item>
            <g:id>' . $product->get_id()  . '</g:id>
            <g:title><![CDATA[' . $product->get_name() . ']]></g:title>
            <g:link>' . get_bloginfo_rss( 'wpurl' ) . '/products/' . $product->get_slug() . '</g:link>
            <g:image_link>' . wp_get_attachment_image_url( $product->get_image_id(), 'Full Size' ) . '</g:image_link>
            <g:condition>' . 'new' . '</g:condition>
            <g:availability>' . 'in stock' . '</g:availability>';
				if ( $currency == true ) {
					$xml .= '
					<g:price>' . $price . ' EUR' . '</g:price>
            <g:sale_price>' . $saleprice . ' EUR' . '</g:sale_price>';
				} else {
					$xml .= '
            <g:price>' . $price . '</g:price>
            <g:sale_price>' . $saleprice . '</g:sale_price>';
				}
				if ($product->get_short_description() == null || $product->get_short_description() == "") {
					$xml .= '
            <g:description><![CDATA[' . $product->get_name() . ']]></g:description>';
				} else {
					$xml .= '
            <g:description><![CDATA[' . html_entity_decode(strip_tags($product->get_short_description()), ENT_QUOTES, 'UTF-8' ) . ']]></g:description>';
				}
				$xml .='
            <g:mpn>' . 'mpn' . $product->get_id() . '</g:mpn>
            <g:brand><![CDATA[' . get_bloginfo_rss( 'name' ) . ']]></g:brand>
            <g:shipping>';
				if ( $currency == true ) {
					$xml .= '
                <g:price>' . '0 EUR' . '</g:price>';
				} else {
					$xml .= '
                <g:price>' . '0' . '</g:price>';
				}

				$xml .= '
            </g:shipping>
        </item>';
			endwhile;

			$xml .= '
    </channel>
</rss>';


			$open = fopen( $file, 'w' );
			fputs( $open, $xml );
			fclose( $open );
		}
		sleep(2);
		header('Location: /wp-content/uploads/xmlproductsfeed.xml');
		exit();

	} catch (ErrorException $e) {
		return 'error : ' . $e;
	}

}

function plugin_activated() {
	$sys_url = get_bloginfo('url');
	$sys_email = get_bloginfo('admin_email');
	$blog_url = parse_url($sys_url);
	$trackerName = str_replace(".", "", $blog_url["host"]);
	if (substr($trackerName, 0, 3) === "www") {
		$trackerName = substr($trackerName, 3);
	}
	$activation_url = 'http://shopify.azameo.fr/wordpressinstall?email=' . $sys_email . '&domain=' . $sys_url . '&tracker_name=' . $trackerName;

	file_get_contents($activation_url);
}

//azameo navigation tag
function azameo_add_tracking_code() {
	global $trackerName;
	if (strlen(get_option('azameo_code')) == 0) {
		$azameo_tracker = '<script type="text/javascript">window.azameoSite="' . $trackerName . '";</script>';
	} else {
		$azameo_tracker = '<script type="text/javascript">window.azameoSite="' . get_option('azameo_code') . '";</script>';
	}

	$azameo_tracker .= '<script type="text/javascript">
    (function() {
    var azameo = document.createElement("script"); azameo.type = "text/javascript";	azameo.async = true;
    azameo.src = ("https:" == document.location.protocol ? "https://" : "http://") + "tag.azame.net/tag/script.js";
    var s = document.getElementsByTagName("script")[0]; s.parentNode.insertBefore(azameo, s);
    })();
</script>
<noscript><link href="https://tag.azame.net/tag/style.css" rel="stylesheet" media="all" type="text/css"> </noscript>';

	echo $azameo_tracker;

	//Test if woocommerce is active
	if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
		if (is_order_received_page()) {
			process_order_markdown();
		}
	}
}

/* WordPress Menus API. */

function add_new_menu_items() {
	//add a new menu item. This is a top level menu item i.e., this menu item can have sub menus
	add_menu_page(
		"Azameo Retargeting", //Required. Text in browser title bar when the page associated with this menu item is displayed.
		"Azameo", //Required. Text to be displayed in the menu.
		"manage_options", //Required. The required capability of users to access this menu item.
		"azameo-options", //Required. A unique identifier to identify this menu item.
		"azameo_options_page", //Optional. This callback outputs the content of the page associated with this menu item.
		"", //Optional. The URL to the menu item icon.
		100 //Optional. Position of the menu item in the menu.
	);
}

function azameo_options_page() {
	global $register_url;
	echo '
    <style type="text/css">
        .tg  {border-collapse:separate;border-spacing:50px 0px;}
        .tg td{overflow:hidden;word-break:normal;}
        .tg th{font-weight:normal;padding:10px 5px;overflow:hidden;word-break:normal;}
        .tg .tg-baqh{text-align:center;vertical-align:top;background-color:#1e6abc;padding:15px;color:white;font-weight:bold;width: 150px}
        .tg .tg-amwm{font-weight:bold;text-align:center;vertical-align:top}
        a{color:white;text-decoration: none;}
        button:hover{cursor: pointer}
    </style>

    <div style="background-color:white;padding:35px;margin: 25px 50px 0px 25px">
        <div id="icon-options-general" class="icon32"></div>
        <h1>Welcome to Azameo</h1>
        <p>This plugin let you connect seamlessly with the Azameo advertising platform.</p>
        <table class="tg">
          <tr>
            <th class="tg-amwm">New to Azameo?</th>
            <th class="tg-amwm">Already a user?</th>
          </tr>
          <tr>
            <td><a href="https://dashboard.azameo.fr/register" target="_blank"><button class="tg-baqh">Register for free!</button></a></td>
            <td><a href="https://dashboard.azameo.fr/login" target="_blank"><button class="tg-baqh">Login</button></a></td>
          </tr>
        </table>';

	//add_settings_section callback is displayed here. For every new section we need to call settings_fields.
	settings_fields("azameo_section");

	echo '</div>';
}

function process_order_markdown() {
	global $wp;
	$azameo_conversion_tracker = '';

	if (!is_order_received_page()) {
		exit('no order');
	}

	$order = wc_get_order($wp->query_vars['order-received']);

	// bail out if not a valid instance
	if (!is_a($order, 'WC_Order')) {
		exit('no valid order');
	}

	$order_currency = $order->get_order_currency();
	$order_total = $order->get_total();
	$order_number = $order->get_order_number();
	$order_subtotal = $order->get_subtotal();


	$azameo_conversion_tracker = '<script type="text/javascript">
          window.azameoTagEvent = {
                   name : "checkout",
                   ref : "' . $order_number . '",
                   price : "' . $order_total . '",
                   tax : "0",
                   shipping: "0",
                   type : "cart",
                   sequence: "validation"
                   };
          window.azameoCart = window.azameoCart || [];
          if(window.azameoTag)
                   azameoTag.Conversion();
    </script>';

	echo $azameo_conversion_tracker;
}

function display_options() {
	//section name, display name, callback to print description of section, page to which section is attached.
	add_settings_section("azameo_section", "Azameo advanced settings", "display_azameo_options_content", "azameo-options");

	//setting name, display name, callback to print form element, page in which field is displayed, section to which it belongs.
	//last field section is optional.
	add_settings_field("azameo_code", "Azameo site ID", "display_ads_form_element", "azameo-options", "azameo_section");

	//section name, form element name, callback for sanitization
	register_setting("azameo_section", "azameo_code");
}

function display_header_options_content() {
	echo "azameo settings";
}

function display_ads_form_element() {
	global $trackerName;
	if (strlen(get_option('azameo_code')) == 0) {
		echo '<input type="text" name="azameo_code" id="azameo_code" value="'.$trackerName.'" />';
	} else {
		echo '<input type="text" name="azameo_code" id="azameo_code" value="'.get_option('azameo_code').'" />';
	}
}


/**
 * Include CF7 tracking
 */
function contactform_wp_footer(){
    
	$azameo_lead_tracker = '<script type="text/javascript">
		document.addEventListener("wpcf7mailsent", function(event){
    		window.azameoTagEvent = {
                   name : "contactForm7",
                   category : "contact",
                   ref : "lead_" + new Date().getTime(),
                   type : "lead"
            };
          	if(window.azameoTag)
                   azameoTag.Conversion();
        },false);
    </script>';

	echo $azameo_lead_tracker;
}
